HboxSpacing Example
===============================================================================

:download:`hbox_spacing.enaml <../../../examples/layout/basic/hbox_spacing.enaml>`

.. literalinclude:: ../../../examples/layout/basic/hbox_spacing.enaml
    :language: python

::

 $ enaml-run hbox_spacing.enaml

.. image:: images/hbox_spacing.png
